@@ -20,6 +20,9 @@ def get_ft_level(input_row):
     return utils.get_fft_level(input_row)
 
 
+def get_pg_level(input_row):
+    return get_ft_level(input_row)
+
 def get_pg(input_row):
     centered_row = get_ft(input_row)
     res_pg = centered_row.values.size ** (-2) * abs(centered_row.values) ** 2
